==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AIntBaseType.h <==
// public final class soot.jimple.parser.node.AIntBaseType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 34d196e3bbe444d3 soot_jimple_parser_node_AIntBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_AIntBaseType_H_
#define _JC_soot_jimple_parser_node_AIntBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TInt$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AIntBaseType$sub_refs	_jc_soot_jimple_parser_node_AIntBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_AIntBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseType$refs	_jc_soot_jimple_parser_node_AIntBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseType$nonrefs	_jc_soot_jimple_parser_node_AIntBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseType$object	_jc_soot_jimple_parser_node_AIntBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_AIntBaseType$vmethods	_jc_soot_jimple_parser_node_AIntBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AIntBaseType$vtable	_jc_soot_jimple_parser_node_AIntBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AIntBaseType$vtype	_jc_soot_jimple_parser_node_AIntBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AIntBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *);
extern void _jc_soot_jimple_parser_node_AIntBaseType$method$_init$2da21b9e71fc9816(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_soot_jimple_parser_node_TInt$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AIntBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AIntBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *);
extern struct _jc_soot_jimple_parser_node_TInt$object *_jc_soot_jimple_parser_node_AIntBaseType$method$getInt$9989ca416f9368a2(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *);
extern void _jc_soot_jimple_parser_node_AIntBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AIntBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AIntBaseType$method$setInt$ecd6687e1107740d(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_soot_jimple_parser_node_TInt$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AIntBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseType$method_info$getInt$9989ca416f9368a2;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseType$method_info$setInt$ecd6687e1107740d;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AIntBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *);
	struct _jc_soot_jimple_parser_node_TInt$object	*(*getInt$9989ca416f9368a2)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setInt$ecd6687e1107740d)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_soot_jimple_parser_node_TInt$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AIntBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_AIntBaseType$vmethods	soot_jimple_parser_node_AIntBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AIntBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AIntBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AIntBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TInt$object	*__5fint__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AIntBaseType$refs {
    _jc_soot_jimple_parser_node_AIntBaseType$sub_refs	soot_jimple_parser_node_AIntBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AIntBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AIntBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_AIntBaseType$sub_nonrefs	soot_jimple_parser_node_AIntBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AIntBaseType$object {
	_jc_soot_jimple_parser_node_AIntBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AIntBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AIntBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AIntBaseType$vtype _jc_soot_jimple_parser_node_AIntBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AIntBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AIntBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AIntBaseType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AIntBaseType.h <==
// public final class soot.jimple.parser.node.AIntBaseType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 34d196e3bbe444d3 soot_jimple_parser_node_AIntBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_AIntBaseType_H_
#define _JC_soot_jimple_parser_node_AIntBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TInt$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AIntBaseType$sub_refs	_jc_soot_jimple_parser_node_AIntBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_AIntBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseType$refs	_jc_soot_jimple_parser_node_AIntBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseType$nonrefs	_jc_soot_jimple_parser_node_AIntBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseType$object	_jc_soot_jimple_parser_node_AIntBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_AIntBaseType$vmethods	_jc_soot_jimple_parser_node_AIntBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AIntBaseType$vtable	_jc_soot_jimple_parser_node_AIntBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AIntBaseType$vtype	_jc_soot_jimple_parser_node_AIntBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AIntBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AIntBaseType$method$_init$2da21b9e71fc9816(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_soot_jimple_parser_node_TInt$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AIntBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AIntBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TInt$object *_jc_soot_jimple_parser_node_AIntBaseType$method$getInt$9989ca416f9368a2(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AIntBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AIntBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AIntBaseType$method$setInt$ecd6687e1107740d(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_soot_jimple_parser_node_TInt$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AIntBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseType$method_info$getInt$9989ca416f9368a2;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseType$method_info$setInt$ecd6687e1107740d;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AIntBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TInt$object	*(*getInt$9989ca416f9368a2)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setInt$ecd6687e1107740d)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *, struct _jc_soot_jimple_parser_node_TInt$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AIntBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_AIntBaseType$vmethods	soot_jimple_parser_node_AIntBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AIntBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AIntBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AIntBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TInt$object	*__5fint__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AIntBaseType$refs {
    _jc_soot_jimple_parser_node_AIntBaseType$sub_refs	soot_jimple_parser_node_AIntBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AIntBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AIntBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_AIntBaseType$sub_nonrefs	soot_jimple_parser_node_AIntBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AIntBaseType$object {
	_jc_soot_jimple_parser_node_AIntBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AIntBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AIntBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AIntBaseType$vtype _jc_soot_jimple_parser_node_AIntBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AIntBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AIntBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AIntBaseType_H_ */
